@@ -3,7 +3,7 @@ package Net::FullAuto::ISets::Amazon::KaliLinux_is;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright © 2000-2016  Brian M. Kelly
+#    Copyright © 2000-2015  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -93,7 +93,7 @@ my $install_dashboard_on_kalilinux=sub {
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
    eval {
@@ -127,7 +127,7 @@ my $configure_kalilinux=sub {
       Net::FullAuto::FA_Core::cleanup();
    }
    ($stdout,$stderr)=$handle->cmd("sudo ln -sf ".
-       "/usr/share/debootstrap/scripts/{wheezy,kali}");
+       "/usr/share/debootstrap/scripts/{wheezy,sana}");
    # BUILDING uses Jazmine Figlet Font
    my $install_kali=<<'END';
 
