@@ -1279,7 +1279,7 @@ Model::TheSchwartz:
 END
 print "LINE 1267\n";
    ($stdout,$stderr)=$handle->cmd("echo \"$content\" >> adventrest.yml");
-print "LINE 1268\n":
+print "LINE 1268\n";
    $ad="use Net::FullAuto;%NL%".
        "use ZMQ::LibZMQ4;%NL%".
        "use ZMQ::Constants qw(:all);%NL%".
